# PyBigBuy

**PyBigBuy** is a Python client for BigBuy’s REST API.

Note: PyBigBuy is not affiliated to nor endorsed by BigBuy.

## Coverage

As of 3.17.0 PyBigBuy implements all API endpoints.
We release new versions of the API client each time we notice new or modified endpoints.

## Install

### Pip

    python -m pip install pybigbuy

### Poetry

    poetry add pybigbuy

## Usage

```python3
from bigbuy import BigBuy


client = BigBuy("your-API-token")
```

## License

Copyright 2020-2023 [Bixoto](https://bixoto.com/).
